@@ -7,6 +7,7 @@ import copy
 import glob
 import json
 import logging
+import os
 import sys
 from pathlib import Path
 from typing import Dict
@@ -339,7 +340,7 @@ class CliArgs:
         usage = (
             "\nBasic: cfn-lint test.yaml\n"
             "Ignore a rule: cfn-lint -i E3012 -- test.yaml\n"
-            "Configure a rule: cfn-lint -x E3012:strict=false -t test.yaml\n"
+            "Configure a rule: cfn-lint -x E3012:strict=true -t test.yaml\n"
             "Lint all yaml files in a folder: cfn-lint dir/**/*.yaml"
         )
 
@@ -464,7 +465,7 @@ class CliArgs:
             nargs="+",
             default={},
             action=RuleConfigurationAction,
-            help="Provide configuration for a rule. Format RuleId:key=value. Example: E3012:strict=false",
+            help="Provide configuration for a rule. Format RuleId:key=value. Example: E3012:strict=true",
         )
         standard.add_argument(
             "--config-file",
@@ -584,6 +585,9 @@ class TemplateArgs:
                         if config_name == "configure_rules":
                             if isinstance(config_value, dict):
                                 defaults["configure_rules"] = config_value
+                        if config_name == "include_experimental":
+                            if isinstance(config_value, bool):
+                                defaults["include_experimental"] = config_value
 
         self._template_args = defaults
 
@@ -615,7 +619,9 @@ class ConfigMixIn(TemplateArgs, CliArgs, ConfigFileArgs):
                 # the CLI will always have an empty list when the item is a list
                 # we will use that to evaluate if we need to merge the lists
                 if isinstance(cli_value, list):
-                    result = cli_value
+                    # Use a copy here, otherwise we will accumulate template level config
+                    # into the cli_value which will  persist between template files
+                    result = cli_value.copy()
                     if isinstance(template_value, list):
                         result.extend(template_value)
                     if isinstance(file_value, list):
@@ -652,7 +658,8 @@ class ConfigMixIn(TemplateArgs, CliArgs, ConfigFileArgs):
     def regions(self):
         results = self._get_argument_value("regions", True, True)
         if not results:
-            return ["us-east-1"]
+            default_region_env = os.environ.get("AWS_DEFAULT_REGION", "us-east-1")
+            return [os.environ.get("AWS_REGION", default_region_env)]
         if "ALL_REGIONS" in results:
             return REGIONS
         return results
