@@ -15,6 +15,7 @@ from json.decoder import (  # type: ignore
 from json.scanner import NUMBER_RE
 
 import cfnlint
+from cfnlint.decode.mark import Mark
 from cfnlint.decode.node import dict_node, list_node, str_node, sub_node
 
 LOGGER = logging.getLogger(__name__)
@@ -74,7 +75,6 @@ class JSONDecodeError(ValueError):
     # Note that this exception is used from _json
 
     def __init__(self, doc, pos, errors):
-
         if isinstance(errors, cfnlint.rules.Match):
             errors = [errors]
 
@@ -92,7 +92,6 @@ class JSONDecodeError(ValueError):
 
 
 def build_match(message, doc, pos, key=" "):
-
     lineno = doc.count("\n", 0, pos) + 1
     colno = pos - doc.rfind("\n", 0, pos)
 
@@ -119,17 +118,6 @@ def build_match_from_key(message, key):
     )
 
 
-class Mark:
-    """Mark of line and column"""
-
-    line = 1
-    column = 1
-
-    def __init__(self, line, column):
-        self.line = line
-        self.column = column
-
-
 # pylint: disable=W0102
 # Exception based on builtin Python Function
 def py_scanstring(s, end, strict=True, _b=BACKSLASH, _m=STRINGCHUNK.match):
