@@ -4,7 +4,7 @@ SPDX-License-Identifier: MIT-0
 """
 from __future__ import unicode_literals
 
-import re
+import regex as re
 
 from cfnlint.rules import CloudFormationLintRule, RuleMatch
 
@@ -35,11 +35,19 @@ class Used(CloudFormationLintRule):
     def match(self, cfn):
         matches = []
 
+        le_refs = None
+        if cfn.has_language_extensions_transform():
+            le_refs = cfn.search_deep_keys("Ref")
+
         reftrees = cfn.transform_pre.get("Ref")
         subtrees = cfn.transform_pre.get("Fn::Sub")
         refs = []
         for reftree in reftrees:
             refs.append(reftree[-1])
+        if le_refs:
+            for le_ref in le_refs:
+                if le_ref[-1] not in refs:
+                    refs.append(le_ref[-1])
         subs = []
         for subtree in subtrees:
             if isinstance(subtree[-1], list):
